@@ -9,8 +9,8 @@
 use super::{Mapping, MsgContext};
 use crate::messaging::{
     data::{DataCmd, DataMsg, ProcessMsg, QueryResponse},
-    node::{NodeCmd, NodeMsg, NodeQuery, NodeQueryResponse, NodeSystemCmd},
-    DataAuthority, DataSigned, DstLocation, MessageId, SrcLocation, WireMsg,
+    node::{NodeCmd, NodeMsg, NodeQuery, NodeQueryResponse},
+    Authority, DataSigned, DstLocation, MessageId, SrcLocation, WireMsg,
 };
 use crate::node::{
     error::convert_to_error_message,
@@ -69,9 +69,9 @@ pub(super) fn map_node_msg(
 fn match_node_msg(msg_id: MessageId, msg: MessageReceived, origin: SrcLocation) -> NodeDuty {
     match msg {
         // Churn synch
-        MessageReceived::NodeCmd(NodeCmd::System(NodeSystemCmd::ReceiveExistingData {
-            metadata,
-        })) => NodeDuty::SynchState { metadata },
+        MessageReceived::NodeCmd(NodeCmd::ReceiveExistingData { metadata }) => {
+            NodeDuty::SynchState { metadata }
+        }
         // ------ metadata ------
         MessageReceived::NodeQuery(NodeQuery::Metadata {
             query,
@@ -132,17 +132,18 @@ fn match_node_msg(msg_id: MessageId, msg: MessageReceived, origin: SrcLocation)
             }
         }
         // this cmd is accumulated, thus has authority
-        MessageReceived::NodeCmd(NodeCmd::System(NodeSystemCmd::ReplicateChunk(chunk))) => {
+        MessageReceived::NodeCmd(NodeCmd::ReplicateChunk(chunk)) => {
             NodeDuty::ReplicateChunk { chunk, msg_id }
         }
-        MessageReceived::NodeCmd(NodeCmd::System(NodeSystemCmd::RepublishChunk(chunk))) => {
+        // Send a message to a section telling them to initiate replication of this chunk
+        MessageReceived::NodeCmd(NodeCmd::RepublishChunk(chunk)) => {
             NodeDuty::ProcessRepublish { chunk, msg_id }
         }
         //
         // ------ system cmd ------
-        MessageReceived::NodeCmd(NodeCmd::System(NodeSystemCmd::StorageFull {
-            node_id, ..
-        })) => NodeDuty::IncrementFullNodeCount { node_id },
+        MessageReceived::NodeCmd(NodeCmd::StorageFull { node_id, .. }) => {
+            NodeDuty::IncrementFullNodeCount { node_id }
+        }
         // --- Adult Operation response ---
         MessageReceived::NodeQueryResponse {
             response: NodeQueryResponse::GetChunk(res),
@@ -166,9 +167,9 @@ fn verify_data_authority(
     origin: SrcLocation,
     data_signed: DataSigned,
     msg: ProcessMsg,
-) -> Result<DataAuthority, NodeDuty> {
+) -> Result<Authority<DataSigned>, NodeDuty> {
     WireMsg::serialize_msg_payload(&DataMsg::Process(msg))
-        .and_then(|payload| data_signed.verify(&payload))
+        .and_then(|payload| Authority::verify(data_signed, &payload))
         .map_err(|error| send_error(msg_id, origin, Error::Message(error), false))
 }
 
