@@ -6,7 +6,7 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use crate::dbs::{convert_to_error_message, Error, RegisterOpStore, Result, UsedSpace};
+use crate::dbs::{convert_to_error_message, Error, EventStore, Result, UsedSpace};
 use crate::types::{
     register::{Action, Address, Register, User},
     PublicKey,
@@ -33,6 +33,8 @@ use xor_name::{Prefix, XorName};
 
 const DATABASE_NAME: &str = "register";
 
+type RegisterOpStore = EventStore<RegisterCmd>;
+
 /// Operations over the data type Register.
 // TODO: dont expose this
 #[derive(Clone, Debug)]
@@ -385,3 +387,75 @@ impl Display for RegisterStorage {
         write!(formatter, "RegisterStorage")
     }
 }
+
+#[cfg(test)]
+mod test {
+    use super::RegisterOpStore;
+    use crate::messaging::data::{RegisterCmd, RegisterWrite};
+    use crate::messaging::DataSigned;
+    use crate::node::Result;
+
+    use crate::node::Error;
+    use crate::types::{
+        register::{PublicPermissions, PublicPolicy, Register, User},
+        Keypair,
+    };
+    use rand::rngs::OsRng;
+    use std::collections::BTreeMap;
+    use std::path::Path;
+    use tempfile::tempdir;
+    use xor_name::XorName;
+
+    #[tokio::test(flavor = "multi_thread")]
+    async fn appends_and_reads_from_store() -> Result<()> {
+        let id = xor_name::XorName::random();
+        let tmp_dir = tempdir()?;
+        let db_dir = tmp_dir.into_path().join(Path::new(&"db".to_string()));
+        let db = sled::open(db_dir).map_err(|error| {
+            trace!("Sled Error: {:?}", error);
+            Error::Sled(error)
+        })?;
+        let mut store = RegisterOpStore::new(id, db)?;
+
+        let authority_keypair1 = Keypair::new_ed25519(&mut OsRng);
+        let pk = authority_keypair1.public_key();
+
+        let register_name: XorName = rand::random();
+        let register_tag = 43_000u64;
+
+        let mut permissions = BTreeMap::default();
+        let user_perms = PublicPermissions::new(true);
+        let _ = permissions.insert(User::Key(pk), user_perms);
+
+        let replica1 = Register::new_public(
+            pk,
+            register_name,
+            register_tag,
+            Some(PublicPolicy {
+                owner: pk,
+                permissions,
+            }),
+        );
+
+        let write = RegisterWrite::New(replica1);
+
+        let client_sig = DataSigned {
+            public_key: pk,
+            signature: authority_keypair1.sign(b""),
+        };
+
+        let cmd = RegisterCmd { write, client_sig };
+
+        store.append(cmd.clone())?;
+
+        let events = store.get_all()?;
+        assert_eq!(events.len(), 1);
+
+        match events.get(0) {
+            Some(found_cmd) => assert_eq!(found_cmd, &cmd),
+            None => unreachable!(),
+        }
+
+        Ok(())
+    }
+}
